/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JDBCConnectionsModelLocator.as 18499 2009-09-03 14:25:10Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.jdbcconnections.model {

import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.model.ModelLocator;

import mx.collections.ArrayCollection;

import org.ow2.jonas.admin.jdbcconnections.business.*;
import org.ow2.jonas.admin.jdbcconnections.view.JDBCConnectionsView;
import org.ow2.jonas.admin.jdbcconnections.vo.JDBCDatasourceInfoVO;
import org.ow2.jonas.admin.jdbcconnections.vo.JNDIInterceptorsConfigurationVO;


/**
 * Cairngorm Model Locator for the JDBC Connections module
 * @author Florent Benoit
 */
[Bindable]
public class JDBCConnectionsModelLocator implements ModelLocator {

    /**
     * The unique ID of this component
     *
     * @internal
     *   Used to prevent a Cairngorm issue: when a command event is dispatched,
     * every controller that registered this event type receives it, even if
     * located in another module. To prevent this from happening and triggering
     * multiple severe unexpected concurrence bugs, each event dispatched is
     * postfixed with this unique ID.
     */
    public var componentID : String = UIDUtil.createUID();

    /**
     * Singleton instance of this locator
     */
    private static var unique : JDBCConnectionsModelLocator;


    /**
     * Link to the view.
     */
    private var jdbcConnectionsView : JDBCConnectionsView = null;

    /**
     * JNDI Interceptors configuration.
     */
    private var jndiInterceptorsConfigurationVO : JNDIInterceptorsConfigurationVO = null;

	/**
	 * JDBC Datasource info
	 */
	 private  var datasourceInfoVO : JDBCDatasourceInfoVO = null;


    /**
     * Information on all the active JDBC Connections of the selected datasource.
     */
    [ArrayElementType(JDBCConnectionInfoVO)]
    public var activeJDBCConnectionsInfoArrayCollectionVO : ArrayCollection;
	 
    /**
     * Displays advanced columns for the JDBC Connections infos.
     */
    private var showAdvancedJDBCConnectionsInfoValue : Boolean = false;
	 	 
    /**
     * Delegate for config.
     */
    private var jndiInterceptordelegate : IGetJNDIInterceptorsConfigurationDelegate = null;

    /**
     * Delegate for the setter of the regexp.
     */
    private var jndiInterceptorSetRegexpValueDelegate : ISetRegexpJNDIInterceptorsConfigurationDelegate = null;

    /**
     * Delegate for the setter of the forceClose.
     */
    private var jndiInterceptorSetForceCloseDelegate : ISetForceCloseJNDIInterceptorsConfigurationDelegate = null;

    /**
     * Delegate for finding JDBC Datasources.
     */
    private var availableJdbcDatasourcesDelegate : IGetJDBCDatasourcesDelegate = null;

    /**
     * Delegate for getting info for a given JDBC Datasource ObjectName.
     */
    private var getJdbcDatasourceInfoDelegate : IGetJDBCDatasourceInfoDelegate = null;

    /**
     * Delegate for getting info on all opened connections of a given JDBC Datasource ObjectName.
     */
    private var getJdbcConnectionsInfoDelegate : IGetJDBCConnectionsInfoDelegate = null;

    /**
     * Delegate for killing a JDBC Connection on a given JDBC Datasource ObjectName.
     */
    private var killJDBCConnectionDelegate : IKillAJDBConnectionDelegate = null;

    /**
     * Allows to update the observable flag on a given JDBC Datasource ObjectName.
     */
    private var observableDatasourceDelegateObject : ISetObservableDataSourceDelegate = null;


    /**
     * Xml data of the datasources (all JDBC Datasources available on the remote side).
     */
    private var availableJdbcDatasources : XML = null;


    /**
     * Value of the selected Datasource ObjectName.
     */
    private var selectedJDBCDatasourceObjectNameText : String;


    /**
     * The datasources needs to be refreshed by the timer.
     */
    private var refreshListDatasourcesValue : Boolean = true;

    /**
     * The datasource info needs to be refreshed by the timer.
     */
    private var refreshDatasourceInfoValue : Boolean = true;

    /**
     * The JDBC Connection info needs to be refreshed by the timer.
     */
    private var refreshJdbcConnectionsInfoValue : Boolean = true;


    /**
     * AutonomousModelLocator singleton instance getter
     */
    public static function getInstance() : JDBCConnectionsModelLocator {
        if (unique == null) {

            // Instanciate the ModelLocator
            unique = new JDBCConnectionsModelLocator();
        }
        return unique;
    }

    /**
     * Constructor
     */
    public function JDBCConnectionsModelLocator() {
        // Instanciate the singleton
        if (unique != null) {
            throw new Error("Error: Singletons can only be" + "instantiated via getInstance() method!");
        }
        JDBCConnectionsModelLocator.unique = this;


        // Delegates
        this.jndiInterceptordelegate = new GetJNDIInterceptorsConfigurationDelegate();
        this.jndiInterceptorSetRegexpValueDelegate = new SetRegexpJNDIInterceptorsConfigurationDelegate();
        this.jndiInterceptorSetForceCloseDelegate = new SetForceCloseJNDIInterceptorsConfigurationDelegate();
        this.availableJdbcDatasourcesDelegate = new GetJDBCDatasourcesDelegate();
        this.getJdbcDatasourceInfoDelegate = new GetJDBCDatasourceInfoDelegate();
        this.getJdbcConnectionsInfoDelegate = new GetJDBCConnectionsInfoDelegate();
        this.killJDBCConnectionDelegate = new KillAJDBCConnectionDelegate();
        this.observableDatasourceDelegateObject = new SetObservableDataSourceDelegate();
    }

    public function get jndiInterceptorsConfiguration() : JNDIInterceptorsConfigurationVO {
        return jndiInterceptorsConfigurationVO;
    }


    public function set jndiInterceptorsConfiguration(jndiInterceptorsConfigurationVO : JNDIInterceptorsConfigurationVO) : void {
        this.jndiInterceptorsConfigurationVO = jndiInterceptorsConfigurationVO;
    }



    public function get jndiInterceptorsConfigurationDelegate() : IGetJNDIInterceptorsConfigurationDelegate {
        return jndiInterceptordelegate;
    }

    public function get jndiInterceptorsSetRegexpValueDelegate() : ISetRegexpJNDIInterceptorsConfigurationDelegate {
        return jndiInterceptorSetRegexpValueDelegate;
    }


    public function get jdbcDatasources() : XML {
        return availableJdbcDatasources;
    }


    public function set jdbcDatasources(availableJdbcDatasources : XML) : void {
        this.availableJdbcDatasources = availableJdbcDatasources;
    }


    public function get jndiInterceptorsSetForceCloseValueDelegate() : ISetForceCloseJNDIInterceptorsConfigurationDelegate {
        return jndiInterceptorSetForceCloseDelegate;
    }

    public function get jdbcDatasourcesDelegate() : IGetJDBCDatasourcesDelegate {
        return availableJdbcDatasourcesDelegate;
    }

    public function get jdbcDatasourceInfoDelegate() : IGetJDBCDatasourceInfoDelegate {
        return getJdbcDatasourceInfoDelegate;
    }

    public function get jdbcConnectionsInfoDelegate() : IGetJDBCConnectionsInfoDelegate {
        return getJdbcConnectionsInfoDelegate;
    }


    public function get killAJDBCConnectionDelegate() : IKillAJDBConnectionDelegate {
        return killJDBCConnectionDelegate;
    }


    public function get observableDatasourceDelegate() : ISetObservableDataSourceDelegate {
        return observableDatasourceDelegateObject;
    }
    
    

    public function set view(jdbcConnectionsView : JDBCConnectionsView) : void {
        this.jdbcConnectionsView = jdbcConnectionsView;
    }

    public function dispatch(event : CairngormEvent) : void {
        jdbcConnectionsView.dispatchEvent(event);

    }


    public function set datasourceInfo(datasourceInfoVO : JDBCDatasourceInfoVO) : void {
        this.datasourceInfoVO = datasourceInfoVO;
    }
    
    public function get datasourceInfo() : JDBCDatasourceInfoVO {
        return datasourceInfoVO;
    }
    

    public function get selectedJDBCDatasourceObjectName() : String {
        return selectedJDBCDatasourceObjectNameText;
    }


    public function set selectedJDBCDatasourceObjectName(selectedJDBCDatasourceObjectNameText : String) : void {
        this.selectedJDBCDatasourceObjectNameText = selectedJDBCDatasourceObjectNameText;
    }

	public function get showAdvancedJDBCConnectionsInfo() : Boolean {
		return showAdvancedJDBCConnectionsInfoValue;
	}

	public function set showAdvancedJDBCConnectionsInfo(showAdvancedJDBCConnectionsInfoValue : Boolean) : void {
		this.showAdvancedJDBCConnectionsInfoValue = showAdvancedJDBCConnectionsInfoValue;
	}
	
	public function get refreshListDatasources() : Boolean {
		return refreshListDatasourcesValue;
	}

	public function set refreshListDatasources(refreshListDatasourcesValue : Boolean) : void {
		this.refreshListDatasourcesValue = refreshListDatasourcesValue;
	}
	
		
	public function get refreshDatasourceInfo() : Boolean {
		return refreshDatasourceInfoValue;
	}

	public function set refreshDatasourceInfo(refreshDatasourceInfoValue : Boolean) : void {
		this.refreshDatasourceInfoValue = refreshDatasourceInfoValue;
	}
	
		
	public function get refreshJdbcConnectionsInfo() : Boolean {
		return refreshJdbcConnectionsInfoValue;
	}

	public function set refreshJdbcConnectionsInfo(refreshJdbcConnectionsInfoValue : Boolean) : void {
		this.refreshJdbcConnectionsInfoValue = refreshJdbcConnectionsInfoValue;
	}


}
}
